"""Data representation for sensors.

This module serves as a centralized import interface for various sensor and camera-related classes and
enumerations used throughout the inference system. By importing and defining `__all__`, it restricts the
module's public API to specific classes, simplifying access and reducing namespace pollution when imported
elsewhere.

The exposed classes cover fundamental components such as sensors, cameras, data representations, and
state tracking, providing the necessary types for handling sensor and camera operations, including specialized
configurations for Time-of-Flight (ToF) cameras.
"""

from dataspree.inference.sensor.data.sensor import Sensor, SensorData, SensorState, SensorStateTransition
from dataspree.inference.sensor.data.camera import Camera, CameraData, CameraModel
from dataspree.inference.sensor.data.tof_camera import TofCamera, TofCameraData

__all__ = [
    'SensorData',
    'Sensor',
    'SensorState',
    'SensorStateTransition',
    'CameraModel',
    'Camera',
    'CameraData',
    'TofCameraData',
    'TofCamera',
]
